@@ -25,7 +25,10 @@ def item_str2dict(s : str, missing : Optional[str] =None) -> dict:
             .split(",")
     dic = OrderedDict()
     for l in lis:
-        k,v = l.split("=")
+        try:
+            k,v = l.split("=")
+        except:
+            raise Exception(f"Split by '=' should be 2 compositions :\nItems: {l}")
         k = k.strip(" ").strip("　")
         if isinstance(k, str) and k.isnumeric():
             k = float(k)
@@ -63,6 +66,14 @@ def imputate_reorder_table(
         if i not in table_.index:
             table_.loc[i]=0
 
+    # Accept "All"
+    for c in table_.columns:
+        if c == "All":
+            cols_.append(c)
+    for i in table_.index:
+        if i == "All":
+            rows_.append(i)
+
     if allow_except:
         for c in table_.columns:
             if c not in cols_:
@@ -109,3 +120,29 @@ def delete_and_create_csv(save_num_path : str) -> None:
         os.remove(save_num_path)
     with open(save_num_path,"w") as f:
         f.write("")
+
+class PathOutput:
+    def __init__(self, path : Optional[str]) -> None:
+        """Generate a list of output path from one path.
+        """
+        self.raw = path
+        if not isinstance(path, type(None)):
+            name, ext = os.path.splitext(path)
+            self.label_only = name + "_label_only" + ext
+            self.no_label = name + "_no_label" + ext
+        else:
+            self.label_only = None
+            self.no_label = None
+
+def delete_All_from_index_column(tab : pd.DataFrame) -> pd.DataFrame:
+    """Delete "All" row and column from dataframe. 
+    """
+    All = "All"
+    if All in tab.index: 
+        tab = tab.drop(index=All)
+    if All in tab.columns:
+        tab = tab.drop(columns=All)
+    return(tab)
+
+
+
